# Generated by Django 4.1.7 on 2023-02-22 21:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nets_core', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='verificationcode',
            name='token',
            field=models.CharField(max_length=150, verbose_name='Verification token'),
        ),
    ]
