# Generated by Django 4.1.7 on 2023-08-16 05:18

from django.db import migrations, models
import shortuuid.main


class Migration(migrations.Migration):

    dependencies = [
        ('nets_core', '0003_userdevice'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userdevice',
            name='device_id',
        ),

    ]
