# Generated by Django 4.1.7 on 2023-08-16 20:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nets_core', '0008_verificationcode_ip_userfirebasenotification'),
    ]

    operations = [
        migrations.AddField(
            model_name='userdevice',
            name='ip',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='IP'),
        ),
    ]
