# Generated by Django 4.1.7 on 2023-08-16 05:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nets_core', '0005_userdevice_uuid'),
    ]

    operations = [
        migrations.AddField(
            model_name='verificationcode',
            name='device',
            field=models.CharField(blank=True, max_length=150, null=True, verbose_name='nets_core.UserDevice'),
        ),
    ]
